import express, { Express } from 'express';
import { __path, prisma } from '../index.js';
import * as Sentry from '@sentry/node';

// Middleware Imports
import { checkAuthentication } from '../middleware/auth.mw.js'

// Route imports
import frontend_routes from './frontend/index.js';
import static_routes from './static/index.js';
import api_routes from './api/index.js';
import auth_routes from './auth/index.js';

const Router = express.Router({ strict: false });

Router.use('/static', static_routes);
Router.use('/api', checkAuthentication, api_routes);
Router.use('/auth', auth_routes);
Router.use('/', checkAuthentication, frontend_routes);

// The error handler must be before any other error middleware and after all controllers
Router.use(Sentry.Handlers.errorHandler());

// Default route.
Router.all('*', function (req, res) {
	// TODO: Respond based on content-type (with req.is('application/json'))
	if (req.is('application/json')) {
		res.status(404).json({ errorcode: 'NOT_FOUND', error: 'Not Found!' });
	} else {
		res.status(404).render(__path + '/src/frontend/errors/404.eta.html', { url: req.originalUrl });
	}
});

export default Router;

